@@ -85,6 +85,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     "rank" in include and parse_rank(p, selector=sel)
     "thumbnail" in include and parse_thumbnail(p, selector=sel)
     "category" in include and parse_category(p, selector=sel)
+    "currency" in include and parse_currency(p, selector=sel)
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
@@ -145,8 +146,7 @@ def parse_price(p: Product, selector: parsel.Selector = None):
         return t
 
     def s1() -> str:
-        s = selector.xpath("//span[@id='priceblock_ourprice']/text()").get()
-        s = s or selector.xpath("//div[@id='buyNew_noncbb']/span/text()").get()
+        s = selector.xpath("//div[@id='buyNew_noncbb']/span/text()").get()
         s = s or selector.xpath("//*[@id='color_name_0_price']/span/text()[last()]").get()
         s = s or selector.xpath("//span[@id='sns-base-price']/text()").get()
         s = s or selector.xpath("//div[@id='olp_feature_div']//span[@class='a-size-base a-color-price']/text()").get()
@@ -155,13 +155,14 @@ def parse_price(p: Product, selector: parsel.Selector = None):
     def s2() -> str:
         t = price_table()
         if numpy.all(t["price"] == ""):
-            return ""
+            price = ""
         elif numpy.any(t["price"] == ""):
-            return str(t["price"][t["price"] != ""][0])
+            price = t["price"][t["price"] != ""][0]
         else:
-            return str(t.at["origin", "price"])
+            price = t.at["origin", "price"]
+        return "" if pandas.isna(price) else str(price)
 
-    prices_str = s1() or s2()
+    prices_str = s2() or s1()
     prices: Union[None, list] = parse_number(prices_str.replace(",", ""), first=False)
     if prices is None or len(prices) == 0:
         p.price_min = None
@@ -455,3 +456,7 @@ def parse_category(p: Product, selector: parsel.Selector = None):
         p.category = None
     else:
         p.category = category
+
+
+def parse_currency(p: Product, selector: parsel.Selector = None):
+    p.currency = None
